"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from neuralseek import models, utils
from neuralseek._hooks import HookContext
from neuralseek.types import OptionalNullable, UNSET
from neuralseek.utils import get_security_from_env
from typing import Mapping, Optional


class OneTimePassword(BaseSDK):
    def create(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.OtpResponseBody:
        r"""Create a One Time Password

        Create a One Time Password for use instead of an api key in unsecure environments, such as the browser. The password will expire after one use, and is valid for 30 minutes. This password can only be used for seek, mAIstro, extract, categorize, score, and logs operations.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="POST",
            path="/otp",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="otp",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.OtpResponseBody)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.OtpResponseBody:
        r"""Create a One Time Password

        Create a One Time Password for use instead of an api key in unsecure environments, such as the browser. The password will expire after one use, and is valid for 30 minutes. This password can only be used for seek, mAIstro, extract, categorize, score, and logs operations.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="POST",
            path="/otp",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="otp",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.OtpResponseBody)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CategorizeRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    question: NotRequired[str]
    r"""The text to categorize"""


class CategorizeRequestBody(BaseModel):
    r"""The request object."""

    question: Optional[str] = ""
    r"""The text to categorize"""


class TopIntentsTypedDict(TypedDict):
    r"""If Vector Similarity is set as the Intent Match type, this will provide the top 3 matches"""

    score: NotRequired[float]
    r"""The score of the intent"""
    intent: NotRequired[str]
    r"""The intent name"""


class TopIntents(BaseModel):
    r"""If Vector Similarity is set as the Intent Match type, this will provide the top 3 matches"""

    score: Optional[float] = None
    r"""The score of the intent"""

    intent: Optional[str] = ""
    r"""The intent name"""


class CategorizeResponseBodyTypedDict(TypedDict):
    r"""Success"""

    intent: NotRequired[str]
    r"""The matched Intent"""
    category: NotRequired[str]
    r"""The matched Category"""
    category_id: NotRequired[int]
    r"""The Category id"""
    top_intents: NotRequired[TopIntentsTypedDict]
    r"""If Vector Similarity is set as the Intent Match type, this will provide the top 3 matches"""


class CategorizeResponseBody(BaseModel):
    r"""Success"""

    intent: Optional[str] = ""
    r"""The matched Intent"""

    category: Optional[str] = ""
    r"""The matched Category"""

    category_id: Annotated[Optional[int], pydantic.Field(alias="categoryId")] = None
    r"""The Category id"""

    top_intents: Annotated[Optional[TopIntents], pydantic.Field(alias="topIntents")] = (
        None
    )
    r"""If Vector Similarity is set as the Intent Match type, this will provide the top 3 matches"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OtpResponseBodyTypedDict(TypedDict):
    r"""Success"""

    otp: NotRequired[str]
    r"""The one time password"""


class OtpResponseBody(BaseModel):
    r"""Success"""

    otp: Optional[str] = ""
    r"""The one time password"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .analyticsop import AnalyticsRequestBody, AnalyticsRequestBodyTypedDict
from .answerratingsop import (
    AnswerRatingsRequestBody,
    AnswerRatingsRequestBodyTypedDict,
    AnswerRatingsResponseBody,
    AnswerRatingsResponseBodyTypedDict,
)
from .apierror import APIError
from .categorizeop import (
    CategorizeRequestBody,
    CategorizeRequestBodyTypedDict,
    CategorizeResponseBody,
    CategorizeResponseBodyTypedDict,
    TopIntents,
    TopIntentsTypedDict,
)
from .deleteuserdataop import DeleteUserDataRequest, DeleteUserDataRequestTypedDict
from .extractentitiesop import (
    ExtractEntitiesRequestBody,
    ExtractEntitiesRequestBodyTypedDict,
    ExtractEntitiesResponseBody,
    ExtractEntitiesResponseBodyTypedDict,
    ExtractEntitiesSlots,
    ExtractEntitiesSlotsTypedDict,
    ExtractedEntities,
    ExtractedEntitiesTypedDict,
    Slots,
    SlotsTypedDict,
)
from .identifylanguagejsonop import (
    IdentifyLanguageJSONRequestBody,
    IdentifyLanguageJSONRequestBodyTypedDict,
    IdentifyLanguageJSONResponseBody,
    IdentifyLanguageJSONResponseBodyTypedDict,
)
from .identifylanguageop import ResponseBody, ResponseBodyTypedDict
from .logsop import (
    LogsRequestBody,
    LogsRequestBodyTypedDict,
    LogsResponseBody,
    LogsResponseBodyTypedDict,
)
from .maistroop import (
    MaistroLastTurn,
    MaistroLastTurnTypedDict,
    MaistroOptions,
    MaistroOptionsTypedDict,
    MaistroParams,
    MaistroParamsTypedDict,
    MaistroRequest,
    MaistroRequestBody,
    MaistroRequestBodyTypedDict,
    MaistroRequestTypedDict,
    MaistroResponseBody,
    MaistroResponseBodyTypedDict,
    MaistroVariables,
    MaistroVariablesExpanded,
    MaistroVariablesExpandedTypedDict,
    MaistroVariablesTypedDict,
    Render,
    RenderTypedDict,
    Vars,
    VarsTypedDict,
)
from .otpop import OtpResponseBody, OtpResponseBodyTypedDict
from .piiop import (
    PiiRequestBody,
    PiiRequestBodyTypedDict,
    PiiResponseBody,
    PiiResponseBodyTypedDict,
)
from .rateop import RateRequestBody, RateRequestBodyTypedDict
from .scoreop import ScoreRequestBody, ScoreRequestBodyTypedDict
from .security import Security, SecurityTypedDict
from .seek import (
    LastTurn,
    LastTurnTypedDict,
    Metadata,
    MetadataTypedDict,
    Options,
    OptionsTypedDict,
    Params,
    ParamsTypedDict,
    Personalize,
    PersonalizeTypedDict,
    Seek,
    SeekTypedDict,
    System,
    SystemTypedDict,
    UserSession,
    UserSessionTypedDict,
)
from .seek_response import (
    Passages,
    PassagesTypedDict,
    SeekResponse,
    SeekResponseTypedDict,
    Variables,
    VariablesExpanded,
    VariablesExpandedTypedDict,
    VariablesTypedDict,
)
from .test_jsonop import TestJSONRequestBody, TestJSONRequestBodyTypedDict
from .test_multipartop import (
    TestMultipartFile,
    TestMultipartFileTypedDict,
    TestMultipartRequestBody,
    TestMultipartRequestBodyTypedDict,
)
from .trainop import TrainRequestBody, TrainRequestBodyTypedDict
from .translateglossary_jsonop import (
    Sentences,
    SentencesTypedDict,
    TranslateGlossaryJSONRequestBody,
    TranslateGlossaryJSONRequestBodyTypedDict,
)
from .translateglossary_multipartop import (
    File,
    FileTypedDict,
    TranslateGlossaryMultipartRequestBody,
    TranslateGlossaryMultipartRequestBodyTypedDict,
)
from .translateop import (
    TranslateRequestBody,
    TranslateRequestBodyTypedDict,
    TranslateResponseBody,
    TranslateResponseBodyTypedDict,
    Translations,
    TranslationsTypedDict,
)


__all__ = [
    "APIError",
    "AnalyticsRequestBody",
    "AnalyticsRequestBodyTypedDict",
    "AnswerRatingsRequestBody",
    "AnswerRatingsRequestBodyTypedDict",
    "AnswerRatingsResponseBody",
    "AnswerRatingsResponseBodyTypedDict",
    "CategorizeRequestBody",
    "CategorizeRequestBodyTypedDict",
    "CategorizeResponseBody",
    "CategorizeResponseBodyTypedDict",
    "DeleteUserDataRequest",
    "DeleteUserDataRequestTypedDict",
    "ExtractEntitiesRequestBody",
    "ExtractEntitiesRequestBodyTypedDict",
    "ExtractEntitiesResponseBody",
    "ExtractEntitiesResponseBodyTypedDict",
    "ExtractEntitiesSlots",
    "ExtractEntitiesSlotsTypedDict",
    "ExtractedEntities",
    "ExtractedEntitiesTypedDict",
    "File",
    "FileTypedDict",
    "IdentifyLanguageJSONRequestBody",
    "IdentifyLanguageJSONRequestBodyTypedDict",
    "IdentifyLanguageJSONResponseBody",
    "IdentifyLanguageJSONResponseBodyTypedDict",
    "LastTurn",
    "LastTurnTypedDict",
    "LogsRequestBody",
    "LogsRequestBodyTypedDict",
    "LogsResponseBody",
    "LogsResponseBodyTypedDict",
    "MaistroLastTurn",
    "MaistroLastTurnTypedDict",
    "MaistroOptions",
    "MaistroOptionsTypedDict",
    "MaistroParams",
    "MaistroParamsTypedDict",
    "MaistroRequest",
    "MaistroRequestBody",
    "MaistroRequestBodyTypedDict",
    "MaistroRequestTypedDict",
    "MaistroResponseBody",
    "MaistroResponseBodyTypedDict",
    "MaistroVariables",
    "MaistroVariablesExpanded",
    "MaistroVariablesExpandedTypedDict",
    "MaistroVariablesTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "Options",
    "OptionsTypedDict",
    "OtpResponseBody",
    "OtpResponseBodyTypedDict",
    "Params",
    "ParamsTypedDict",
    "Passages",
    "PassagesTypedDict",
    "Personalize",
    "PersonalizeTypedDict",
    "PiiRequestBody",
    "PiiRequestBodyTypedDict",
    "PiiResponseBody",
    "PiiResponseBodyTypedDict",
    "RateRequestBody",
    "RateRequestBodyTypedDict",
    "Render",
    "RenderTypedDict",
    "ResponseBody",
    "ResponseBodyTypedDict",
    "ScoreRequestBody",
    "ScoreRequestBodyTypedDict",
    "Security",
    "SecurityTypedDict",
    "Seek",
    "SeekResponse",
    "SeekResponseTypedDict",
    "SeekTypedDict",
    "Sentences",
    "SentencesTypedDict",
    "Slots",
    "SlotsTypedDict",
    "System",
    "SystemTypedDict",
    "TestJSONRequestBody",
    "TestJSONRequestBodyTypedDict",
    "TestMultipartFile",
    "TestMultipartFileTypedDict",
    "TestMultipartRequestBody",
    "TestMultipartRequestBodyTypedDict",
    "TopIntents",
    "TopIntentsTypedDict",
    "TrainRequestBody",
    "TrainRequestBodyTypedDict",
    "TranslateGlossaryJSONRequestBody",
    "TranslateGlossaryJSONRequestBodyTypedDict",
    "TranslateGlossaryMultipartRequestBody",
    "TranslateGlossaryMultipartRequestBodyTypedDict",
    "TranslateRequestBody",
    "TranslateRequestBodyTypedDict",
    "TranslateResponseBody",
    "TranslateResponseBodyTypedDict",
    "Translations",
    "TranslationsTypedDict",
    "UserSession",
    "UserSessionTypedDict",
    "Variables",
    "VariablesExpanded",
    "VariablesExpandedTypedDict",
    "VariablesTypedDict",
    "Vars",
    "VarsTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from neuralseek import models, utils
from neuralseek._hooks import HookContext
from neuralseek.types import BaseModel, OptionalNullable, UNSET
from neuralseek.utils import get_security_from_env
from typing import Mapping, Optional, Union, cast


class Categorize(BaseSDK):
    def execute(
        self,
        *,
        request: Union[
            models.CategorizeRequestBody, models.CategorizeRequestBodyTypedDict
        ] = models.CategorizeRequestBody(),
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CategorizeResponseBody:
        r"""Categorize text into an Intent & Category

        Categorize text into an Intent & Category

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CategorizeRequestBody)
        request = cast(models.CategorizeRequestBody, request)

        req = self._build_request(
            method="POST",
            path="/categorize",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, True, "json", Optional[models.CategorizeRequestBody]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="categorize",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.CategorizeResponseBody)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def execute_async(
        self,
        *,
        request: Union[
            models.CategorizeRequestBody, models.CategorizeRequestBodyTypedDict
        ] = models.CategorizeRequestBody(),
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CategorizeResponseBody:
        r"""Categorize text into an Intent & Category

        Categorize text into an Intent & Category

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CategorizeRequestBody)
        request = cast(models.CategorizeRequestBody, request)

        req = self._build_request_async(
            method="POST",
            path="/categorize",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, True, "json", Optional[models.CategorizeRequestBody]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="categorize",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.CategorizeResponseBody)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ScoreRequestBodyTypedDict(TypedDict):
    r"""The request object.  Must include the question and a context."""

    text: NotRequired[str]
    r"""The text to score"""
    passages: NotRequired[List[str]]
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""


class ScoreRequestBody(BaseModel):
    r"""The request object.  Must include the question and a context."""

    text: Optional[str] = ""
    r"""The text to score"""

    passages: Optional[List[str]] = None
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AnalyticsRequestBodyTypedDict(TypedDict):
    r"""The request object.  You may optionally limit the result set using \"count\" """

    count: NotRequired[int]
    r"""The number of rows to return"""


class AnalyticsRequestBody(BaseModel):
    r"""The request object.  You may optionally limit the result set using \"count\" """

    count: Optional[int] = None
    r"""The number of rows to return"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AnswerRatingsRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    answer_id: NotRequired[int]
    r"""The answer id"""
    number: NotRequired[int]
    r"""The number of previous user ratings to average. Leave blank to average all ratings."""


class AnswerRatingsRequestBody(BaseModel):
    r"""The request object."""

    answer_id: Annotated[Optional[int], pydantic.Field(alias="answerId")] = None
    r"""The answer id"""

    number: Optional[int] = None
    r"""The number of previous user ratings to average. Leave blank to average all ratings."""


class AnswerRatingsResponseBodyTypedDict(TypedDict):
    r"""Success"""

    score: NotRequired[float]
    r"""The average score for the answer."""
    total: NotRequired[float]
    r"""The total number of user ratings for the answer."""


class AnswerRatingsResponseBody(BaseModel):
    r"""Success"""

    score: Optional[float] = None
    r"""The average score for the answer."""

    total: Optional[float] = None
    r"""The total number of user ratings for the answer."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from neuralseek.types import BaseModel
from neuralseek.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class TestMultipartFileTypedDict(TypedDict):
    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class TestMultipartFile(BaseModel):
    __test__ = False

    file_name: Annotated[
        str, pydantic.Field(alias="fileName"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class TestMultipartRequestBodyTypedDict(TypedDict):
    r"""The questions csv.  Must adhere to the template https://api.neuralseek.com/q.csv After upload you will receive a 202 response and the server will begin processing.  Check for your completed results on the getTestResults endpoint."""

    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    file: NotRequired[TestMultipartFileTypedDict]


class TestMultipartRequestBody(BaseModel):
    r"""The questions csv.  Must adhere to the template https://api.neuralseek.com/q.csv After upload you will receive a 202 response and the server will begin processing.  Check for your completed results on the getTestResults endpoint."""

    __test__ = False

    file: Annotated[
        Optional[TestMultipartFile],
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TranslateRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    text: NotRequired[List[str]]
    r"""An array of input text to be translated"""
    model_id: NotRequired[str]
    r"""Convienence input for legacy connections. Define a traget language by setting a source to target relationship using 2-digit language codes, for example en-es to translate into spanish.  The source language is ignored. Either this or the target parameter is required."""
    target: NotRequired[str]
    r"""The 2-digit language code for the target language.  Either this or the model_id parameter is required."""
    llm_id: NotRequired[str]
    r"""Optional - Pass an llm card id to override the LLM used for translation"""
    max_chunk: NotRequired[int]
    r"""Optional - Pass a maximum translation chunk token size. This can help speed up translations in the 200-2000 word range when using slower LLM's.  Use a setting between 200 and 500 in these scenarios. Setting 0 or omitting this parameter unsets it."""
    additional_instructions: NotRequired[str]
    r"""Optional - Additional prompting to be passed to the LLM. Do not casusally use this field, you will break things."""


class TranslateRequestBody(BaseModel):
    r"""The request object."""

    text: Optional[List[str]] = None
    r"""An array of input text to be translated"""

    model_id: Optional[str] = ""
    r"""Convienence input for legacy connections. Define a traget language by setting a source to target relationship using 2-digit language codes, for example en-es to translate into spanish.  The source language is ignored. Either this or the target parameter is required."""

    target: Optional[str] = ""
    r"""The 2-digit language code for the target language.  Either this or the model_id parameter is required."""

    llm_id: Annotated[Optional[str], pydantic.Field(alias="llmId")] = ""
    r"""Optional - Pass an llm card id to override the LLM used for translation"""

    max_chunk: Annotated[Optional[int], pydantic.Field(alias="maxChunk")] = 0
    r"""Optional - Pass a maximum translation chunk token size. This can help speed up translations in the 200-2000 word range when using slower LLM's.  Use a setting between 200 and 500 in these scenarios. Setting 0 or omitting this parameter unsets it."""

    additional_instructions: Annotated[
        Optional[str], pydantic.Field(alias="additionalInstructions")
    ] = ""
    r"""Optional - Additional prompting to be passed to the LLM. Do not casusally use this field, you will break things."""


class TranslationsTypedDict(TypedDict):
    translation: NotRequired[str]
    r"""The translation"""


class Translations(BaseModel):
    translation: Optional[str] = ""
    r"""The translation"""


class TranslateResponseBodyTypedDict(TypedDict):
    r"""Success"""

    word_count: NotRequired[int]
    r"""The word count."""
    character_count: NotRequired[int]
    r"""The word count."""
    detected_language: NotRequired[str]
    r"""The 2-digit language code for the detected language."""
    detected_language_confidence: NotRequired[float]
    r"""The detected language confidence."""
    translation_glossary: NotRequired[bool]
    r"""Returns true if a glossary is loaded and matched any input."""
    translation_glossary_exact: NotRequired[bool]
    r"""Returns true if a glossary is loaded and an entry exactly matched the input."""
    translations: NotRequired[List[TranslationsTypedDict]]


class TranslateResponseBody(BaseModel):
    r"""Success"""

    word_count: Optional[int] = None
    r"""The word count."""

    character_count: Optional[int] = None
    r"""The word count."""

    detected_language: Optional[str] = ""
    r"""The 2-digit language code for the detected language."""

    detected_language_confidence: Optional[float] = None
    r"""The detected language confidence."""

    translation_glossary: Optional[bool] = None
    r"""Returns true if a glossary is loaded and matched any input."""

    translation_glossary_exact: Optional[bool] = None
    r"""Returns true if a glossary is loaded and an entry exactly matched the input."""

    translations: Optional[List[Translations]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IdentifyLanguageJSONRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    input: NotRequired[str]
    r"""The input text to identify the language of"""


class IdentifyLanguageJSONRequestBody(BaseModel):
    r"""The request object."""

    input: Optional[str] = ""
    r"""The input text to identify the language of"""


class IdentifyLanguageJSONResponseBodyTypedDict(TypedDict):
    r"""Success"""

    language: NotRequired[str]
    r"""The 2-character language code of the identified language."""
    confidence: NotRequired[float]
    r"""The confidence of the language identification"""


class IdentifyLanguageJSONResponseBody(BaseModel):
    r"""Success"""

    language: Optional[str] = ""
    r"""The 2-character language code of the identified language."""

    confidence: Optional[float] = None
    r"""The confidence of the language identification"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TrainRequestBodyTypedDict(TypedDict):
    r"""The request object.  Must include the question and a context."""

    train: NotRequired[str]
    r"""The training token. Get this from passages/train"""
    score: NotRequired[int]
    r"""The relevancy score. An integer, 0-100"""


class TrainRequestBody(BaseModel):
    r"""The request object.  Must include the question and a context."""

    train: Optional[str] = ""
    r"""The training token. Get this from passages/train"""

    score: Optional[int] = None
    r"""The relevancy score. An integer, 0-100"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PiiRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    text: NotRequired[str]
    r"""The user utterance to check for PII"""


class PiiRequestBody(BaseModel):
    r"""The request object."""

    text: Optional[str] = ""
    r"""The user utterance to check for PII"""


class PiiResponseBodyTypedDict(TypedDict):
    pii: NotRequired[List[str]]
    r"""An array of found PII"""


class PiiResponseBody(BaseModel):
    pii: Optional[List[str]] = None
    r"""An array of found PII"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
from neuralseek import models, utils
from neuralseek._hooks import SDKHooks
from neuralseek.analytics import Analytics
from neuralseek.answerratings import AnswerRatings
from neuralseek.categorize import Categorize
from neuralseek.extractentities import ExtractEntities
from neuralseek.findpii import FindPII
from neuralseek.identifylanguage import IdentifyLanguage
from neuralseek.identifylanguagejson import IdentifyLanguageJSON
from neuralseek.keycheck import KeyCheck
from neuralseek.logs import Logs
from neuralseek.maistro import Maistro
from neuralseek.onetimepassword import OneTimePassword
from neuralseek.rate import Rate
from neuralseek.score import Score
from neuralseek.seek_sdk import SeekSDK
from neuralseek.servicetest import ServiceTest
from neuralseek.testquestions import TestQuestions
from neuralseek.testresults import TestResults
from neuralseek.train import Train
from neuralseek.translate import Translate
from neuralseek.translationglossary import TranslationGlossary
from neuralseek.types import OptionalNullable, UNSET
from neuralseek.userdata import UserData
from typing import Any, Callable, Dict, List, Optional, Union, cast
import weakref


class Neuralseek(BaseSDK):
    r"""NeuralSeek: NeuralSeek - The business LLM accelerator
    https://documentation.neuralseek.com - Documentation
    """

    seek: SeekSDK
    categorize: Categorize
    maistro: Maistro
    extract_entities: ExtractEntities
    translate: Translate
    translation_glossary: TranslationGlossary
    identify_language: IdentifyLanguage
    identify_language_json: IdentifyLanguageJSON
    find_pii: FindPII
    rate: Rate
    answer_ratings: AnswerRatings
    score: Score
    train: Train
    service_test: ServiceTest
    test_questions: TestQuestions
    test_results: TestResults
    analytics: Analytics
    logs: Logs
    one_time_password: OneTimePassword
    user_data: UserData
    key_check: KeyCheck

    def __init__(
        self,
        api_key: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        instance: Optional[str] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param api_key: The api_key required for authentication
        :param instance: Allows setting the instance variable for url substitution
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        if client is None:
            client = httpx.Client()

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        if async_client is None:
            async_client = httpx.AsyncClient()

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(api_key):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(api_key=api_key())
        else:
            security = models.Security(api_key=api_key)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)
        server_defaults: List[Dict[str, str]] = [
            {
                "instance": instance or "demo",
            },
        ]

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                async_client=async_client,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                server_defaults=server_defaults,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, self.sdk_configuration.client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.async_client,
        )

        self._init_sdks()

    def _init_sdks(self):
        self.seek = SeekSDK(self.sdk_configuration)
        self.categorize = Categorize(self.sdk_configuration)
        self.maistro = Maistro(self.sdk_configuration)
        self.extract_entities = ExtractEntities(self.sdk_configuration)
        self.translate = Translate(self.sdk_configuration)
        self.translation_glossary = TranslationGlossary(self.sdk_configuration)
        self.identify_language = IdentifyLanguage(self.sdk_configuration)
        self.identify_language_json = IdentifyLanguageJSON(self.sdk_configuration)
        self.find_pii = FindPII(self.sdk_configuration)
        self.rate = Rate(self.sdk_configuration)
        self.answer_ratings = AnswerRatings(self.sdk_configuration)
        self.score = Score(self.sdk_configuration)
        self.train = Train(self.sdk_configuration)
        self.service_test = ServiceTest(self.sdk_configuration)
        self.test_questions = TestQuestions(self.sdk_configuration)
        self.test_results = TestResults(self.sdk_configuration)
        self.analytics = Analytics(self.sdk_configuration)
        self.logs = Logs(self.sdk_configuration)
        self.one_time_password = OneTimePassword(self.sdk_configuration)
        self.user_data = UserData(self.sdk_configuration)
        self.key_check = KeyCheck(self.sdk_configuration)

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.client is not None:
            self.sdk_configuration.client.close()

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self.sdk_configuration.async_client is not None:
            await self.sdk_configuration.async_client.aclose()



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseBodyTypedDict(TypedDict):
    language: NotRequired[str]
    r"""The 2-character language code of the identified language."""
    confidence: NotRequired[float]
    r"""The confidence of the language identification."""


class ResponseBody(BaseModel):
    language: Optional[str] = ""
    r"""The 2-character language code of the identified language."""

    confidence: Optional[float] = None
    r"""The confidence of the language identification."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SlotsTypedDict(TypedDict):
    r"""Provide an object of variable names, with a type property set to an entity type to match to in total across multiple turns of a conversation. NeuralSeek will return a promptEntity to display to the user to continue to fil the slots.  As slots are filled the value field will be populated.  Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""


class Slots(BaseModel):
    r"""Provide an object of variable names, with a type property set to an entity type to match to in total across multiple turns of a conversation. NeuralSeek will return a promptEntity to display to the user to continue to fil the slots.  As slots are filled the value field will be populated.  Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""


class ExtractEntitiesRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    text: NotRequired[str]
    r"""The text to extract entitites from"""
    language: NotRequired[str]
    r"""The 2-char language code to be used when generating a promptEntity response. Only set this if you want to override the configured language in NeuralSeek."""
    entities: NotRequired[str]
    r"""An array of objects, stringified. The properties of the object are name, description, and format"""
    slots: NotRequired[SlotsTypedDict]
    r"""Provide an object of variable names, with a type property set to an entity type to match to in total across multiple turns of a conversation. NeuralSeek will return a promptEntity to display to the user to continue to fil the slots.  As slots are filled the value field will be populated.  Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""
    confirm_slots: NotRequired[bool]
    r"""When using Slots, once all slots have been filled display a summary and ask for a confirmation before setting the 'complete' flag"""
    confirm_every_slot: NotRequired[bool]
    r"""When using Slots, on every turn recite the slot that was just previously filled."""


class ExtractEntitiesRequestBody(BaseModel):
    r"""The request object."""

    text: Optional[str] = None
    r"""The text to extract entitites from"""

    language: Optional[str] = None
    r"""The 2-char language code to be used when generating a promptEntity response. Only set this if you want to override the configured language in NeuralSeek."""

    entities: Optional[str] = None
    r"""An array of objects, stringified. The properties of the object are name, description, and format"""

    slots: Optional[Slots] = None
    r"""Provide an object of variable names, with a type property set to an entity type to match to in total across multiple turns of a conversation. NeuralSeek will return a promptEntity to display to the user to continue to fil the slots.  As slots are filled the value field will be populated.  Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""

    confirm_slots: Annotated[Optional[bool], pydantic.Field(alias="confirmSlots")] = (
        None
    )
    r"""When using Slots, once all slots have been filled display a summary and ask for a confirmation before setting the 'complete' flag"""

    confirm_every_slot: Annotated[
        Optional[bool], pydantic.Field(alias="confirmEverySlot")
    ] = None
    r"""When using Slots, on every turn recite the slot that was just previously filled."""


class ExtractedEntitiesTypedDict(TypedDict):
    entity: NotRequired[str]
    r"""The found entity"""


class ExtractedEntities(BaseModel):
    entity: Optional[str] = ""
    r"""The found entity"""


class ExtractEntitiesSlotsTypedDict(TypedDict):
    r"""If the slots parameter is filled on the input, NeuralSeek will return it and begin filling the value fields. Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""


class ExtractEntitiesSlots(BaseModel):
    r"""If the slots parameter is filled on the input, NeuralSeek will return it and begin filling the value fields. Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""


class ExtractEntitiesResponseBodyTypedDict(TypedDict):
    r"""Success"""

    extracted_entities: NotRequired[List[ExtractedEntitiesTypedDict]]
    complete: NotRequired[bool]
    r"""If slots are passed, complete will be set to true when all slots are filled"""
    prompt_entity: NotRequired[str]
    r"""A message to display to the user asking them to provide input for the next group of unfilled slots."""
    slots: NotRequired[ExtractEntitiesSlotsTypedDict]
    r"""If the slots parameter is filled on the input, NeuralSeek will return it and begin filling the value fields. Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""


class ExtractEntitiesResponseBody(BaseModel):
    r"""Success"""

    extracted_entities: Annotated[
        Optional[List[ExtractedEntities]], pydantic.Field(alias="extractedEntities")
    ] = None

    complete: Optional[bool] = False
    r"""If slots are passed, complete will be set to true when all slots are filled"""

    prompt_entity: Annotated[Optional[str], pydantic.Field(alias="promptEntity")] = None
    r"""A message to display to the user asking them to provide input for the next group of unfilled slots."""

    slots: Optional[ExtractEntitiesSlots] = None
    r"""If the slots parameter is filled on the input, NeuralSeek will return it and begin filling the value fields. Continue to send this entire filed back as input thru the multiple turns of the conversation, untill Complete is set to true.  Complete will be set to true when all slots are filled"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RateRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    answer_id: NotRequired[int]
    r"""The answer id"""
    score: NotRequired[int]
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""


class RateRequestBody(BaseModel):
    r"""The request object."""

    answer_id: Annotated[Optional[int], pydantic.Field(alias="answerId")] = None
    r"""The answer id"""

    score: Optional[int] = None
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TestJSONRequestBodyTypedDict(TypedDict):
    r"""The questions csv.  Must adhere to the template https://api.neuralseek.com/q.csv After upload you will receive a 202 response and the server will begin processing.  Check for your completed results on the getTestResults endpoint."""

    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    proposal_id: NotRequired[str]
    r"""An optional Proposal ID to use for the test"""


class TestJSONRequestBody(BaseModel):
    r"""The questions csv.  Must adhere to the template https://api.neuralseek.com/q.csv After upload you will receive a 202 response and the server will begin processing.  Check for your completed results on the getTestResults endpoint."""

    __test__ = False

    proposal_id: Annotated[Optional[str], pydantic.Field(alias="proposalID")] = ""
    r"""An optional Proposal ID to use for the test"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from neuralseek.utils import FieldMetadata, QueryParamMetadata
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteUserDataRequestTypedDict(TypedDict):
    intent: NotRequired[List[str]]
    r"""The intents to delete. If left blank all intents will be deleted."""


class DeleteUserDataRequest(BaseModel):
    intent: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The intents to delete. If left blank all intents will be deleted."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MetadataTypedDict(TypedDict):
    user_id: NotRequired[str]
    r"""A unique user identifier."""


class Metadata(BaseModel):
    user_id: Optional[str] = ""
    r"""A unique user identifier."""


class SystemTypedDict(TypedDict):
    session_id: NotRequired[str]
    r"""A session identifier for the defined user."""


class System(BaseModel):
    session_id: Optional[str] = ""
    r"""A session identifier for the defined user."""


class UserSessionTypedDict(TypedDict):
    r"""Context tracking object. You must set at least one of user_id or session_id to enable context keeping."""

    metadata: NotRequired[MetadataTypedDict]
    system: NotRequired[SystemTypedDict]


class UserSession(BaseModel):
    r"""Context tracking object. You must set at least one of user_id or session_id to enable context keeping."""

    metadata: Optional[Metadata] = None

    system: Optional[System] = None


class ParamsTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The parameter name"""
    value: NotRequired[str]
    r"""The parameter value"""


class Params(BaseModel):
    name: Optional[str] = ""
    r"""The parameter name"""

    value: Optional[str] = ""
    r"""The parameter value"""


class PersonalizeTypedDict(TypedDict):
    r"""An object that allows NeuralSeek to tailor a response for a specific user"""

    preferred_name: NotRequired[str]
    r"""The name the user should be referred to by"""
    no_welcome: NotRequired[str]
    r"""The user has already been welcomed, do not re-welcome.  Valid value is 'true' or 'false'.  Default value is 'false'."""
    force_first_person: NotRequired[str]
    r"""Use a first-person speaking style, even if no preferredName is set.  Valid value is 'true' or 'false'.  Default value is 'false'."""
    products: NotRequired[List[str]]
    r"""An array of products this customer currently consumes from your company"""
    additional_details: NotRequired[str]
    r"""Additional details to pass to language generation"""


class Personalize(BaseModel):
    r"""An object that allows NeuralSeek to tailor a response for a specific user"""

    preferred_name: Annotated[Optional[str], pydantic.Field(alias="preferredName")] = ""
    r"""The name the user should be referred to by"""

    no_welcome: Annotated[Optional[str], pydantic.Field(alias="noWelcome")] = ""
    r"""The user has already been welcomed, do not re-welcome.  Valid value is 'true' or 'false'.  Default value is 'false'."""

    force_first_person: Annotated[
        Optional[str], pydantic.Field(alias="forceFirstPerson")
    ] = ""
    r"""Use a first-person speaking style, even if no preferredName is set.  Valid value is 'true' or 'false'.  Default value is 'false'."""

    products: Optional[List[str]] = None
    r"""An array of products this customer currently consumes from your company"""

    additional_details: Annotated[
        Optional[str], pydantic.Field(alias="additionalDetails")
    ] = ""
    r"""Additional details to pass to language generation"""


class LastTurnTypedDict(TypedDict):
    input: NotRequired[str]
    r"""The user input"""
    response: NotRequired[str]
    r"""The system response.  Text strings only here."""


class LastTurn(BaseModel):
    input: Optional[str] = ""
    r"""The user input"""

    response: Optional[str] = ""
    r"""The system response.  Text strings only here."""


class OptionsTypedDict(TypedDict):
    r"""Optional object for runtime override of Seek options."""

    personalize: NotRequired[PersonalizeTypedDict]
    r"""An object that allows NeuralSeek to tailor a response for a specific user"""
    proposal_id: NotRequired[str]
    r"""Override all settings by passing a NeuralSeek Proposal ID."""
    streaming: NotRequired[bool]
    r"""Return the response via SSE streaming.  This is not compatible with most Virtual Agent platforms, and is intentded for direct website use."""
    seek_llm: NotRequired[str]
    r"""Override the LLM load balancer and force seek to use a specific LLM.  Input the LLM code here.  You must have a valid model card set up on the configure tab for the code you input."""
    language: NotRequired[str]
    r"""Valid values are: en, es, de, it, fr, ja, ar"""
    filter_: NotRequired[str]
    r"""Text to use as a filter against the filter field set in the KnowledgeBase configuration. Use commas to separate multiple strings for an 'or' filter. You can use the filter to isolate a certain subset of documents in the knowledgebase."""
    last_turn: NotRequired[List[LastTurnTypedDict]]
    r"""lastTurn is a flexible object. It is backwards compatible with the original single turn object, as well as compatible with the Watson Assistant session history format."""
    prompt_engineering: NotRequired[str]
    r"""Enable Prompt engineering.  Valid values are the strings 'true' and 'false'"""
    prompt_engineering_phrase: NotRequired[str]
    r"""Prepend a phrase to cleansed user input. Must enable Prompt Engineering inside the NeuralSeek \"Configure\" page"""
    answer_length: NotRequired[int]
    r"""The verbosity of the answer. A whole number 1-4"""
    url: NotRequired[str]
    r"""URL of the current page when using with a web-based Virtual Agent"""
    stump: NotRequired[str]
    r"""Stump Speech text. Fallback for when all else fails."""
    include_source_results: NotRequired[bool]
    r"""Include generation source results. Defaults to false."""
    include_highlights: NotRequired[bool]
    r"""Include highlights from source results. Defaults to false."""
    include_source_results_formatted: NotRequired[bool]
    r"""Include generation source results, and output them into a formatted string.  Defaults to false."""
    source_results_number: NotRequired[int]
    r"""When including source results, how many to include.'"""
    source_results_summary_length: NotRequired[int]
    r"""When including source results, how long of a summary to include.'"""
    return_variables: NotRequired[bool]
    r"""Return the final state of all variables in a dense object"""
    return_variables_expanded: NotRequired[bool]
    r"""Return the final state of all variables in the same format as the input params"""


class Options(BaseModel):
    r"""Optional object for runtime override of Seek options."""

    personalize: Optional[Personalize] = None
    r"""An object that allows NeuralSeek to tailor a response for a specific user"""

    proposal_id: Annotated[Optional[str], pydantic.Field(alias="proposalID")] = ""
    r"""Override all settings by passing a NeuralSeek Proposal ID."""

    streaming: Optional[bool] = False
    r"""Return the response via SSE streaming.  This is not compatible with most Virtual Agent platforms, and is intentded for direct website use."""

    seek_llm: Annotated[Optional[str], pydantic.Field(alias="seekLLM")] = ""
    r"""Override the LLM load balancer and force seek to use a specific LLM.  Input the LLM code here.  You must have a valid model card set up on the configure tab for the code you input."""

    language: Optional[str] = ""
    r"""Valid values are: en, es, de, it, fr, ja, ar"""

    filter_: Annotated[Optional[str], pydantic.Field(alias="filter")] = ""
    r"""Text to use as a filter against the filter field set in the KnowledgeBase configuration. Use commas to separate multiple strings for an 'or' filter. You can use the filter to isolate a certain subset of documents in the knowledgebase."""

    last_turn: Annotated[Optional[List[LastTurn]], pydantic.Field(alias="lastTurn")] = (
        None
    )
    r"""lastTurn is a flexible object. It is backwards compatible with the original single turn object, as well as compatible with the Watson Assistant session history format."""

    prompt_engineering: Annotated[
        Optional[str], pydantic.Field(alias="promptEngineering")
    ] = ""
    r"""Enable Prompt engineering.  Valid values are the strings 'true' and 'false'"""

    prompt_engineering_phrase: Annotated[
        Optional[str], pydantic.Field(alias="promptEngineeringPhrase")
    ] = ""
    r"""Prepend a phrase to cleansed user input. Must enable Prompt Engineering inside the NeuralSeek \"Configure\" page"""

    answer_length: Annotated[Optional[int], pydantic.Field(alias="answerLength")] = None
    r"""The verbosity of the answer. A whole number 1-4"""

    url: Optional[str] = ""
    r"""URL of the current page when using with a web-based Virtual Agent"""

    stump: Optional[str] = ""
    r"""Stump Speech text. Fallback for when all else fails."""

    include_source_results: Annotated[
        Optional[bool], pydantic.Field(alias="includeSourceResults")
    ] = False
    r"""Include generation source results. Defaults to false."""

    include_highlights: Annotated[
        Optional[bool], pydantic.Field(alias="includeHighlights")
    ] = False
    r"""Include highlights from source results. Defaults to false."""

    include_source_results_formatted: Annotated[
        Optional[bool], pydantic.Field(alias="includeSourceResultsFormatted")
    ] = False
    r"""Include generation source results, and output them into a formatted string.  Defaults to false."""

    source_results_number: Annotated[
        Optional[int], pydantic.Field(alias="sourceResultsNumber")
    ] = 3
    r"""When including source results, how many to include.'"""

    source_results_summary_length: Annotated[
        Optional[int], pydantic.Field(alias="sourceResultsSummaryLength")
    ] = 100
    r"""When including source results, how long of a summary to include.'"""

    return_variables: Annotated[
        Optional[bool], pydantic.Field(alias="returnVariables")
    ] = False
    r"""Return the final state of all variables in a dense object"""

    return_variables_expanded: Annotated[
        Optional[bool], pydantic.Field(alias="returnVariablesExpanded")
    ] = False
    r"""Return the final state of all variables in the same format as the input params"""


class SeekTypedDict(TypedDict):
    question: NotRequired[str]
    r"""The user's question for NeuralSeek"""
    user_session: NotRequired[UserSessionTypedDict]
    r"""Context tracking object. You must set at least one of user_id or session_id to enable context keeping."""
    params: NotRequired[List[ParamsTypedDict]]
    r"""An array of parameters to use in evaluation of the seek when calling mAIstro during a seek."""
    options: NotRequired[OptionsTypedDict]
    r"""Optional object for runtime override of Seek options."""


class Seek(BaseModel):
    question: Optional[str] = ""
    r"""The user's question for NeuralSeek"""

    user_session: Optional[UserSession] = None
    r"""Context tracking object. You must set at least one of user_id or session_id to enable context keeping."""

    params: Optional[List[Params]] = None
    r"""An array of parameters to use in evaluation of the seek when calling mAIstro during a seek."""

    options: Optional[Options] = None
    r"""Optional object for runtime override of Seek options."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from neuralseek.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MaistroParamsTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The parameter name"""
    value: NotRequired[str]
    r"""The parameter value"""


class MaistroParams(BaseModel):
    name: Optional[str] = ""
    r"""The parameter name"""

    value: Optional[str] = ""
    r"""The parameter value"""


class MaistroLastTurnTypedDict(TypedDict):
    input: NotRequired[str]
    r"""The user input"""
    response: NotRequired[str]
    r"""The system response.  Text strings only here."""


class MaistroLastTurn(BaseModel):
    input: Optional[str] = ""
    r"""The user input"""

    response: Optional[str] = ""
    r"""The system response.  Text strings only here."""


class MaistroOptionsTypedDict(TypedDict):
    r"""Override options"""

    streaming: NotRequired[bool]
    r"""Return the response via SSE streaming.  This is not compatible with most Virtual Agent platforms, and is intentded for direct website use."""
    llm: NotRequired[str]
    r"""Override the LLM load balancer and force seek to use a specific LLM.  Input the LLM code here.  You must have a valid model card set up on the configure tab for the code you input."""
    user_id: NotRequired[str]
    r"""Set the user_id. Useful and required if you have a corporate document filter set"""
    timeout: NotRequired[float]
    r"""Timeout in miliseconds. (optional)"""
    temperature_mod: NotRequired[float]
    r"""Shift the model's baseline temperature weighting by a percentage"""
    topp_mod: NotRequired[float]
    r"""Shift the model's baseline probability weighting by a percentage"""
    freqpenalty_mod: NotRequired[float]
    r"""Shift the model's baseline frequency penalty weighting by a percentage"""
    min_tokens: NotRequired[float]
    r"""Set the minimum tokens you  want the model to produce"""
    max_tokens: NotRequired[float]
    r"""Set the maximum tokens you  want the model to produce"""
    last_turn: NotRequired[List[MaistroLastTurnTypedDict]]
    r"""lastTurn is a flexible object. It is backwards compatible with the original single turn object, as well as compatible with the Watson Assistant session history format."""
    return_variables: NotRequired[bool]
    r"""Return the final state of all variables in a dense object"""
    return_variables_expanded: NotRequired[bool]
    r"""Return the final state of all variables in the same format as the input params"""
    return_render: NotRequired[bool]
    r"""Return the midstate renders"""
    return_source: NotRequired[bool]
    r"""Return the source parts"""
    max_recursion: NotRequired[int]
    r"""The maximum number of recursive calls to Explore.  Use caution that you have not created an endless loop as you increase the maximum, as each Explore is charged."""


class MaistroOptions(BaseModel):
    r"""Override options"""

    streaming: Optional[bool] = False
    r"""Return the response via SSE streaming.  This is not compatible with most Virtual Agent platforms, and is intentded for direct website use."""

    llm: Optional[str] = ""
    r"""Override the LLM load balancer and force seek to use a specific LLM.  Input the LLM code here.  You must have a valid model card set up on the configure tab for the code you input."""

    user_id: Optional[str] = ""
    r"""Set the user_id. Useful and required if you have a corporate document filter set"""

    timeout: Optional[float] = None
    r"""Timeout in miliseconds. (optional)"""

    temperature_mod: Annotated[
        Optional[float], pydantic.Field(alias="temperatureMod")
    ] = None
    r"""Shift the model's baseline temperature weighting by a percentage"""

    topp_mod: Annotated[Optional[float], pydantic.Field(alias="toppMod")] = None
    r"""Shift the model's baseline probability weighting by a percentage"""

    freqpenalty_mod: Annotated[
        Optional[float], pydantic.Field(alias="freqpenaltyMod")
    ] = None
    r"""Shift the model's baseline frequency penalty weighting by a percentage"""

    min_tokens: Annotated[Optional[float], pydantic.Field(alias="minTokens")] = None
    r"""Set the minimum tokens you  want the model to produce"""

    max_tokens: Annotated[Optional[float], pydantic.Field(alias="maxTokens")] = None
    r"""Set the maximum tokens you  want the model to produce"""

    last_turn: Annotated[
        Optional[List[MaistroLastTurn]], pydantic.Field(alias="lastTurn")
    ] = None
    r"""lastTurn is a flexible object. It is backwards compatible with the original single turn object, as well as compatible with the Watson Assistant session history format."""

    return_variables: Annotated[
        Optional[bool], pydantic.Field(alias="returnVariables")
    ] = False
    r"""Return the final state of all variables in a dense object"""

    return_variables_expanded: Annotated[
        Optional[bool], pydantic.Field(alias="returnVariablesExpanded")
    ] = False
    r"""Return the final state of all variables in the same format as the input params"""

    return_render: Annotated[Optional[bool], pydantic.Field(alias="returnRender")] = (
        False
    )
    r"""Return the midstate renders"""

    return_source: Annotated[Optional[bool], pydantic.Field(alias="returnSource")] = (
        False
    )
    r"""Return the source parts"""

    max_recursion: Annotated[Optional[int], pydantic.Field(alias="maxRecursion")] = 10
    r"""The maximum number of recursive calls to Explore.  Use caution that you have not created an endless loop as you increase the maximum, as each Explore is charged."""


class MaistroRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    ntl: NotRequired[str]
    r"""The NTL script to evaluate.  Include either this or agent - not both"""
    agent: NotRequired[str]
    r"""The agent to use. Include either this or NTL"""
    params: NotRequired[List[MaistroParamsTypedDict]]
    r"""An array of parameters to use in evaluation of the NTL"""
    options: NotRequired[MaistroOptionsTypedDict]
    r"""Override options"""


class MaistroRequestBody(BaseModel):
    r"""The request object."""

    ntl: Optional[str] = ""
    r"""The NTL script to evaluate.  Include either this or agent - not both"""

    agent: Optional[str] = ""
    r"""The agent to use. Include either this or NTL"""

    params: Optional[List[MaistroParams]] = None
    r"""An array of parameters to use in evaluation of the NTL"""

    options: Optional[MaistroOptions] = None
    r"""Override options"""


class MaistroRequestTypedDict(TypedDict):
    request_body: MaistroRequestBodyTypedDict
    r"""The request object."""
    overrideschema: NotRequired[str]
    r"""Find variables based on post body.  Return all variables as the base presponse body, overriding the normal NS schema. All POST options will be ignored. Set this to a string value of 'true' to activate"""
    overrideagent: NotRequired[str]
    r"""If using overrideSchema you must pass your agent name here. All other POST options will be ignored."""
    debug: NotRequired[str]
    r"""Include NS debug information in a field named 'neuralseek'. Set this to a string value of 'true' to activate"""


class MaistroRequest(BaseModel):
    request_body: Annotated[
        MaistroRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""The request object."""

    overrideschema: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = ""
    r"""Find variables based on post body.  Return all variables as the base presponse body, overriding the normal NS schema. All POST options will be ignored. Set this to a string value of 'true' to activate"""

    overrideagent: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = ""
    r"""If using overrideSchema you must pass your agent name here. All other POST options will be ignored."""

    debug: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = ""
    r"""Include NS debug information in a field named 'neuralseek'. Set this to a string value of 'true' to activate"""


class VarsTypedDict(TypedDict):
    r"""The variable values"""


class Vars(BaseModel):
    r"""The variable values"""


class RenderTypedDict(TypedDict):
    node: NotRequired[str]
    r"""The node type"""
    vars: NotRequired[VarsTypedDict]
    r"""The variable values"""
    out: NotRequired[str]
    r"""The output"""
    chained: NotRequired[bool]
    r"""True if the step is chained"""


class Render(BaseModel):
    node: Optional[str] = ""
    r"""The node type"""

    vars: Optional[Vars] = None
    r"""The variable values"""

    out: Optional[str] = ""
    r"""The output"""

    chained: Optional[bool] = None
    r"""True if the step is chained"""


class MaistroVariablesTypedDict(TypedDict):
    r"""The returned variable."""


class MaistroVariables(BaseModel):
    r"""The returned variable."""


class MaistroVariablesExpandedTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The variable name"""
    value: NotRequired[str]
    r"""The variable value"""


class MaistroVariablesExpanded(BaseModel):
    name: Optional[str] = ""
    r"""The variable name"""

    value: Optional[str] = ""
    r"""The variable value"""


class MaistroResponseBodyTypedDict(TypedDict):
    r"""Success"""

    answer: NotRequired[str]
    r"""The generated response"""
    source_parts: NotRequired[List[str]]
    render: NotRequired[List[RenderTypedDict]]
    r"""The steps used to render the result."""
    variables: NotRequired[MaistroVariablesTypedDict]
    r"""The returned variable."""
    variables_expanded: NotRequired[List[MaistroVariablesExpandedTypedDict]]
    r"""The returned variable, in the format of the input params"""


class MaistroResponseBody(BaseModel):
    r"""Success"""

    answer: Optional[str] = ""
    r"""The generated response"""

    source_parts: Annotated[
        Optional[List[str]], pydantic.Field(alias="sourceParts")
    ] = None

    render: Optional[List[Render]] = None
    r"""The steps used to render the result."""

    variables: Optional[MaistroVariables] = None
    r"""The returned variable."""

    variables_expanded: Annotated[
        Optional[List[MaistroVariablesExpanded]],
        pydantic.Field(alias="variablesExpanded"),
    ] = None
    r"""The returned variable, in the format of the input params"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PassagesTypedDict(TypedDict):
    passage: NotRequired[str]
    r"""The passage text, summarized to the length set by sourceResultsSummaryLength"""
    id: NotRequired[str]
    r"""The id of the source document in the KB."""
    score: NotRequired[int]
    r"""The score of the passage."""
    url: NotRequired[str]
    r"""The URL (if available) of the source document."""
    document: NotRequired[str]
    r"""The name of the source document."""
    train: NotRequired[str]
    r"""The training token for the document. Use this when calling the /train endpoint."""


class Passages(BaseModel):
    passage: Optional[str] = ""
    r"""The passage text, summarized to the length set by sourceResultsSummaryLength"""

    id: Optional[str] = ""
    r"""The id of the source document in the KB."""

    score: Optional[int] = None
    r"""The score of the passage."""

    url: Optional[str] = ""
    r"""The URL (if available) of the source document."""

    document: Optional[str] = ""
    r"""The name of the source document."""

    train: Optional[str] = ""
    r"""The training token for the document. Use this when calling the /train endpoint."""


class VariablesTypedDict(TypedDict):
    r"""The returned variable."""


class Variables(BaseModel):
    r"""The returned variable."""


class VariablesExpandedTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The variable name"""
    value: NotRequired[str]
    r"""The variable value"""


class VariablesExpanded(BaseModel):
    name: Optional[str] = ""
    r"""The variable name"""

    value: Optional[str] = ""
    r"""The variable value"""


class SeekResponseTypedDict(TypedDict):
    score: int
    r"""The final confidence score of the answer (0-100)"""
    answer: NotRequired[str]
    r"""The generated answer"""
    answer_id: NotRequired[str]
    r"""The id of the answer. Use this to refer to it from other endpoints, such as the Rating endpoint"""
    thumbs: NotRequired[str]
    r"""The URL of a rating HTML page with an SVG to embed with the answer to allow easy rating."""
    thumbs_svg: NotRequired[str]
    r"""The URL of a rating SVG to display with the answer to allow easy rating."""
    intent: NotRequired[str]
    r"""The intent of the answer."""
    category: NotRequired[int]
    r"""The category id of the answer."""
    category_name: NotRequired[str]
    r"""The category name of the answer."""
    k_bscore: NotRequired[int]
    r"""The KnowledgeBase confidence of the answer's source documentation  (0-100)"""
    cached_result: NotRequired[str]
    r"""If the result came from cache, will be set to the string 'true'"""
    lang_code: NotRequired[str]
    r"""The language code of the answer. If you set the input language code to 'xx' to identify the language, this is useful to condition of the found language and response."""
    url: NotRequired[str]
    r"""The top scoring URL (if available) used to train the answer. Set the field you want returned here in on the Configure tab. The field must contain a URL, or it will be ignored."""
    document: NotRequired[str]
    r"""The top document (if available) used to train the answer. Set the field you want returned here in on the Configure tab"""
    time: NotRequired[int]
    r"""Total processing time in milliseconds"""
    kb_time: NotRequired[int]
    r"""KnowledgeBase response time in milliseconds"""
    source_results_formatted: NotRequired[str]
    r"""A listing of the passages used for answer summarization. This will only return if includeSourceResultsFormatted is set to true on the request"""
    passages: NotRequired[List[PassagesTypedDict]]
    r"""A listing of the passages used for answer summarization. This will only return if includeSourceResults is set to true on the request"""
    kb_coverage: NotRequired[int]
    r"""KnowledgeBase coverage score. How much content was returned from the KnowledgeBase on the subject asked as compared to benchmarks. Low coverage is not necessarily indicitive of bad content."""
    sentiment: NotRequired[int]
    r"""Sentiment score"""
    semantic_score: NotRequired[int]
    r"""Semantic score (if enabled)"""
    variables: NotRequired[VariablesTypedDict]
    r"""The returned variable."""
    variables_expanded: NotRequired[List[VariablesExpandedTypedDict]]
    r"""The returned variable, in the format of the input params"""


class SeekResponse(BaseModel):
    score: int
    r"""The final confidence score of the answer (0-100)"""

    answer: Optional[str] = ""
    r"""The generated answer"""

    answer_id: Annotated[Optional[str], pydantic.Field(alias="answerId")] = ""
    r"""The id of the answer. Use this to refer to it from other endpoints, such as the Rating endpoint"""

    thumbs: Optional[str] = ""
    r"""The URL of a rating HTML page with an SVG to embed with the answer to allow easy rating."""

    thumbs_svg: Annotated[Optional[str], pydantic.Field(alias="thumbsSVG")] = ""
    r"""The URL of a rating SVG to display with the answer to allow easy rating."""

    intent: Optional[str] = ""
    r"""The intent of the answer."""

    category: Optional[int] = None
    r"""The category id of the answer."""

    category_name: Annotated[Optional[str], pydantic.Field(alias="categoryName")] = ""
    r"""The category name of the answer."""

    k_bscore: Annotated[Optional[int], pydantic.Field(alias="KBscore")] = None
    r"""The KnowledgeBase confidence of the answer's source documentation  (0-100)"""

    cached_result: Annotated[Optional[str], pydantic.Field(alias="cachedResult")] = ""
    r"""If the result came from cache, will be set to the string 'true'"""

    lang_code: Annotated[Optional[str], pydantic.Field(alias="langCode")] = ""
    r"""The language code of the answer. If you set the input language code to 'xx' to identify the language, this is useful to condition of the found language and response."""

    url: Optional[str] = ""
    r"""The top scoring URL (if available) used to train the answer. Set the field you want returned here in on the Configure tab. The field must contain a URL, or it will be ignored."""

    document: Optional[str] = ""
    r"""The top document (if available) used to train the answer. Set the field you want returned here in on the Configure tab"""

    time: Optional[int] = None
    r"""Total processing time in milliseconds"""

    kb_time: Annotated[Optional[int], pydantic.Field(alias="kbTime")] = None
    r"""KnowledgeBase response time in milliseconds"""

    source_results_formatted: Annotated[
        Optional[str], pydantic.Field(alias="sourceResultsFormatted")
    ] = ""
    r"""A listing of the passages used for answer summarization. This will only return if includeSourceResultsFormatted is set to true on the request"""

    passages: Optional[List[Passages]] = None
    r"""A listing of the passages used for answer summarization. This will only return if includeSourceResults is set to true on the request"""

    kb_coverage: Annotated[Optional[int], pydantic.Field(alias="kbCoverage")] = None
    r"""KnowledgeBase coverage score. How much content was returned from the KnowledgeBase on the subject asked as compared to benchmarks. Low coverage is not necessarily indicitive of bad content."""

    sentiment: Optional[int] = None
    r"""Sentiment score"""

    semantic_score: Annotated[Optional[int], pydantic.Field(alias="semanticScore")] = (
        None
    )
    r"""Semantic score (if enabled)"""

    variables: Optional[Variables] = None
    r"""The returned variable."""

    variables_expanded: Annotated[
        Optional[List[VariablesExpanded]], pydantic.Field(alias="variablesExpanded")
    ] = None
    r"""The returned variable, in the format of the input params"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class LogsRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    limit: NotRequired[int]
    r"""The number of rows to return, max of 100"""
    skip: NotRequired[int]
    r"""The number of result sets to skip for paging"""
    search: NotRequired[str]
    r"""An optional search string"""


class LogsRequestBody(BaseModel):
    r"""The request object."""

    limit: Optional[int] = 100
    r"""The number of rows to return, max of 100"""

    skip: Optional[int] = 0
    r"""The number of result sets to skip for paging"""

    search: Optional[str] = ""
    r"""An optional search string"""


class LogsResponseBodyTypedDict(TypedDict):
    date_: NotRequired[str]
    r"""The timestamp of the entry"""
    question: NotRequired[str]
    r"""The user question"""
    answer: NotRequired[str]
    r"""The answer returned"""
    id: NotRequired[int]
    r"""The answer id"""


class LogsResponseBody(BaseModel):
    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = ""
    r"""The timestamp of the entry"""

    question: Optional[str] = ""
    r"""The user question"""

    answer: Optional[str] = ""
    r"""The answer returned"""

    id: Optional[int] = None
    r"""The answer id"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from neuralseek.types import BaseModel
from neuralseek.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class FileTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class File(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="fileName"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class TranslateGlossaryMultipartRequestBodyTypedDict(TypedDict):
    r"""This endpoint will accept either a file upload (TMX or JSON), or a direct JSON payload following IBM's JSON file format https://cloud.ibm.com/docs/language-translator?topic=language-translator-customizing#json.  Only one file may be saved. Subsequent files will overwrite."""

    file: NotRequired[FileTypedDict]


class TranslateGlossaryMultipartRequestBody(BaseModel):
    r"""This endpoint will accept either a file upload (TMX or JSON), or a direct JSON payload following IBM's JSON file format https://cloud.ibm.com/docs/language-translator?topic=language-translator-customizing#json.  Only one file may be saved. Subsequent files will overwrite."""

    file: Annotated[
        Optional[File], FieldMetadata(multipart=MultipartFormMetadata(file=True))
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SentencesTypedDict(TypedDict):
    language: NotRequired[str]
    r"""The language code"""
    sentence: NotRequired[str]
    r"""The sentence fragment"""


class Sentences(BaseModel):
    language: Optional[str] = ""
    r"""The language code"""

    sentence: Optional[str] = ""
    r"""The sentence fragment"""


class TranslateGlossaryJSONRequestBodyTypedDict(TypedDict):
    r"""This endpoint will accept either a file upload (TMX or JSON), or a direct JSON payload following IBM's JSON file format https://cloud.ibm.com/docs/language-translator?topic=language-translator-customizing#json.  Only one file may be saved. Subsequent files will overwrite."""

    sentences: NotRequired[List[List[SentencesTypedDict]]]
    r"""Instead of a file upload you may pass sentence mappings"""


class TranslateGlossaryJSONRequestBody(BaseModel):
    r"""This endpoint will accept either a file upload (TMX or JSON), or a direct JSON payload following IBM's JSON file format https://cloud.ibm.com/docs/language-translator?topic=language-translator-customizing#json.  Only one file may be saved. Subsequent files will overwrite."""

    sentences: Optional[List[List[Sentences]]] = None
    r"""Instead of a file upload you may pass sentence mappings"""
